@@ -45,9 +45,9 @@ static const char sccsid[] = "@(#)ant.c	4.07 97/11/24 xlockmore";
 /*-
   Species Grid     Number of Neigbors
   ------- ----     ------------------
-  Ants    Square   4 or 8
+  Ants    Square   4 (or 8)
   Bees    Hexagon  6
-  Bees    Triangle 3 (9? or 12) <- 9 and 12 are not implemented
+  Bees    Triangle 3 (or 9, 12)
 
   Neighbors 6 and neighbors 3 produce the same Turk ants.
 */
@@ -61,15 +61,25 @@ static const char sccsid[] = "@(#)ant.c	4.07 97/11/24 xlockmore";
  "*count: -3 \n" \
  "*cycles: 40000 \n" \
  "*size: -7 \n" \
- "*ncolors: 64 \n"
+ "*ncolors: 64 \n" \
+ "*neighbors: 0 \n" \
+ "*fullrandom: True \n" \
+ "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "erase.h"
+#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+/*-
+ * neighbors of 0 randomizes it between 3, 4 and 6.
+ * 8, 9 12 are available also but not recommended.
+ */
 extern int  neighbors;
 
 #define DEF_TRUCHET  "False"
+
 static Bool truchet;
 
 static XrmOptionDescRec opts[] =
@@ -83,6 +93,9 @@ static argtype vars[] =
 };
 static OptionStruct desc[] =
 {
+#if 0
+      {"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
+#endif
 	{"-/+truchet", "turn on/off Truchet lines"}
 };
 
@@ -124,6 +137,7 @@ typedef struct {
 } antstruct;
 
 typedef struct {
+	Bool        painted;
 	int         neighbors;
 	int         generation;
 	int         xs, ys;
@@ -450,9 +464,17 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 		else
 			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
 			    ap->shape.hexagon, 6, Convex, CoordModePrevious);
+#if 1				/* #ifndef XSCREENSAVER_PREF */
+/*-
+ * jwz sez: this looks like crap 
+ * dab says this is illogical; only squares (neighbors == 4) were in the
+ *   original description of ants, in addition, removing them here is
+ *   incorrect.
+ */
 	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
 		ap->xb + ap->xs * col, ap->yb + ap->ys * row, ap->xs, ap->ys);
+#endif
 	} else {		/* TRI */
 		int         orient = (col + row) % 2;	/* O left 1 right */
 
@@ -705,10 +727,10 @@ getTable(ModeInfo * mi, int i)
 	ap->ncolors = *patptr++;
 	ap->nstates = *patptr++;
 	total = ap->ncolors * ap->nstates;
-	if (MI_WIN_IS_VERBOSE(mi))
+	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-		     "neighbors %d, table number %d, colors %d, states %d\n",
-			       ap->neighbors, i, ap->ncolors, ap->nstates);
+		     "ants %d, neighbors %d, table number %d, colors %d, states %d\n",
+		      ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
 	for (j = 0; j < total; j++) {
 		ap->machine[j].color = *patptr++;
 		ap->machine[j].direction = fromTableDirection(*patptr++, ap->neighbors);
@@ -740,15 +762,16 @@ getTurk(ModeInfo * mi, int i)
 		ap->machine[j].next = 0;
 		power2 >>= 1;
 	}
-	if (MI_WIN_IS_FULLRANDOM(mi))
+	if (MI_IS_FULLRANDOM(mi))
 		ap->truchet = (Bool) (LRAND() & 1);
 	else
 		ap->truchet = truchet;
 	ap->truchet = (ap->truchet && ap->xs > 2 && ap->ys > 2 &&
 	   (ap->neighbors == 3 || ap->neighbors == 4 || ap->neighbors == 6));
-	if (MI_WIN_IS_VERBOSE(mi))
-		(void) fprintf(stdout, "neighbors %d, Turk's number %d, colors %d\n",
-			       ap->neighbors, number, ap->ncolors);
+	if (MI_IS_VERBOSE(mi))
+		(void) fprintf(stdout,
+			    "ants %d, neighbors %d, Turk's number %d, colors %d\n",
+			    ap->n, ap->neighbors, number, ap->ncolors);
 }
 
 void
@@ -766,6 +789,13 @@ init_ant(ModeInfo * mi)
 			return;
 	}
 	ap = &antfarms[MI_SCREEN(mi)];
+#ifdef XSCREENSAVER_PREF
+/* jwz sez: small sizes look like crap, dab says they don't */
+	if (size < 0)
+		size = NRAND(-size) + 1;
+	if (size < 5)
+		size += 5;
+#endif
 	ap->redrawing = 0;
 	if (MI_NPIXELS(mi) <= 2) {
 		if (ap->stippledGC == None) {
@@ -780,7 +810,7 @@ init_ant(ModeInfo * mi)
 		}
 	}
 	ap->generation = 0;
-	ap->n = MI_BATCHCOUNT(mi);
+	ap->n = MI_COUNT(mi);
 	if (ap->n < -MINANTS) {
 		/* if ap->n is random ... the size can change */
 		if (ap->ants != NULL) {
@@ -791,8 +821,8 @@ init_ant(ModeInfo * mi)
 	} else if (ap->n < MINANTS)
 		ap->n = MINANTS;
 
-	ap->width = MI_WIN_WIDTH(mi);
-	ap->height = MI_WIN_HEIGHT(mi);
+	ap->width = MI_WIDTH(mi);
+	ap->height = MI_HEIGHT(mi);
 
 	if (neighbors == 8 || neighbors == 9 || neighbors == 12)
 		ap->neighbors = neighbors;	/* Discourage but not deny use... */
@@ -833,10 +863,13 @@ init_ant(ModeInfo * mi)
 		ap->nrows = 2 * (ncrows / 4);
 		ap->xb = (ap->width - ap->xs * nccols) / 2 + ap->xs / 2;
 		ap->yb = (ap->height - ap->ys * (ncrows / 2) * 2) / 2 + ap->ys;
-		for (i = 0; i < 7; i++) {
+		for (i = 0; i < 6; i++) {
 			ap->shape.hexagon[i].x = (ap->xs - 1) * hexagonUnit[i].x;
 			ap->shape.hexagon[i].y = ((ap->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
 		}
+		/* Avoid array bounds read of hexagonUnit */
+		ap->shape.hexagon[6].x = 0;
+		ap->shape.hexagon[6].y = 0;
 	} else if (ap->neighbors == 4 && ap->neighbors == 8) {
 		if (size < -MINSIZE)
 			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
@@ -878,16 +911,20 @@ init_ant(ModeInfo * mi)
 		ap->xb = (ap->width - ap->xs * ap->ncols) / 2 + ap->xs / 2;
 		ap->yb = (ap->height - ap->ys * ap->nrows) / 2 + ap->ys;
 		for (orient = 0; orient < 2; orient++) {
-			for (i = 0; i < 4; i++) {
+			for (i = 0; i < 3; i++) {
 				ap->shape.triangle[orient][i].x =
 					(ap->xs - 2) * triangleUnit[orient][i].x;
 				ap->shape.triangle[orient][i].y =
 					(ap->ys - 2) * triangleUnit[orient][i].y;
 			}
+			/* Avoid array bounds read of triangleUnit */
+			ap->shape.triangle[orient][3].x = 0;
+			ap->shape.triangle[orient][3].y = 0;
 		}
 	}
 
 	MI_CLEARWINDOW(mi);
+	ap->painted = False;
 
 	/* Exclude odd # of neighbors, stepping forward not defined */
 	if (!NRAND(NUMSTIPPLES) && ((ap->neighbors + 1) % 2)) {
@@ -933,6 +970,7 @@ draw_ant(ModeInfo * mi)
 	unsigned char color;
 	short       chg_dir, old_dir;
 
+	ap->painted = True;
 	for (i = 0; i < ap->n; i++) {
 		anant = &ap->ants[i];
 		tape_pos = anant->col + anant->row * ap->ncols;
@@ -976,8 +1014,12 @@ draw_ant(ModeInfo * mi)
 		position_of_neighbor(ap, old_dir, &(anant->col), &(anant->row));
 		draw_anant(mi, anant->col, anant->row);
 	}
-	if (++ap->generation > MI_CYCLES(mi))
+	if (++ap->generation > MI_CYCLES(mi)) {
+#ifdef STANDALONE
+		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
+#endif
 		init_ant(mi);
+	}
 	if (ap->redrawing) {
 		for (i = 0; i < REDRAWSTEP; i++) {
 			if (ap->tape[ap->redrawpos] ||
@@ -1029,6 +1071,9 @@ refresh_ant(ModeInfo * mi)
 {
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
 
-	ap->redrawing = 1;
-	ap->redrawpos = 0;
+	if (ap->painted) {
+		MI_CLEARWINDOW(mi);
+		ap->redrawing = 1;
+		ap->redrawpos = 0;
+	}
 }
