@@ -95,8 +95,8 @@ init_blot(ModeInfo * mi)
 	}
 	bp = &blots[MI_SCREEN(mi)];
 
-	bp->width = MI_WIN_WIDTH(mi);
-	bp->height = MI_WIN_HEIGHT(mi);
+	bp->width = MI_WIDTH(mi);
+	bp->height = MI_HEIGHT(mi);
 	bp->xmid = bp->width / 2;
 	bp->ymid = bp->height / 2;
 
@@ -107,10 +107,10 @@ init_blot(ModeInfo * mi)
 		bp->pix = NRAND(MI_NPIXELS(mi));
 	if (bp->offset <= 0)
 		bp->offset = 3;
-	if (MI_BATCHCOUNT(mi) < 0)
-		bp->size = NRAND(-MI_BATCHCOUNT(mi) + 1);
+	if (MI_COUNT(mi) < 0)
+		bp->size = NRAND(-MI_COUNT(mi) + 1);
 	else
-		bp->size = MI_BATCHCOUNT(mi);
+		bp->size = MI_COUNT(mi);
 
 	/* Fudge the size so it takes up the whole screen */
 	bp->size *= (unsigned long) (bp->width / 32 + 1) * (bp->height / 32 + 1);
