@@ -135,8 +135,8 @@ init_coral(ModeInfo * mi)
 	cp = &reefs[MI_SCREEN(mi)];
 
 
-	cp->width = MAX(MI_WIN_WIDTH(mi), 2);
-	cp->height = MAX(MI_WIN_HEIGHT(mi), 2);
+	cp->width = MAX(MI_WIDTH(mi), 2);
+	cp->height = MAX(MI_HEIGHT(mi), 2);
 
 	cp->widthb = ((cp->width + 31) >> 5);
 
@@ -166,7 +166,7 @@ init_coral(ModeInfo * mi)
 	if (!cp->walkers)
 		return;
 
-	cp->seeds = MI_BATCHCOUNT(mi);
+	cp->seeds = MI_COUNT(mi);
 	if (cp->seeds < -MINSEEDS)
 		cp->seeds = NRAND(-cp->seeds - MINSEEDS + 1) + MINSEEDS;
 	else if (cp->seeds < MINSEEDS)
