@@ -37,8 +37,10 @@ static const char sccsid[] = "@(#)daisy.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 100000 \n" \
  "*count: 300 \n" \
  "*cycles: 350 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*fullrandom: True \n"
 #define BRIGHT_COLORS
+#define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -252,15 +254,15 @@ init_daisy(ModeInfo * mi)
 	}
 	dp = &daisies[MI_SCREEN(mi)];
 
-	dp->width = MI_WIN_WIDTH(mi);
-	dp->height = MI_WIN_HEIGHT(mi);
+	dp->width = MI_WIDTH(mi);
+	dp->height = MI_HEIGHT(mi);
 	dp->time = 0;
-	if (MI_WIN_IS_FULLRANDOM(mi))
+	if (MI_IS_FULLRANDOM(mi))
 		dp->garden = (Bool) (LRAND() & 1);
 	else
 		dp->garden = garden;
 
-	dp->ndaisies = MI_BATCHCOUNT(mi);
+	dp->ndaisies = MI_COUNT(mi);
 	if (dp->ndaisies < -MINDAISIES)
 		dp->ndaisies = NRAND(-dp->ndaisies - MINDAISIES + 1) + MINDAISIES;
 	else if (dp->ndaisies < MINDAISIES)
