@@ -116,7 +116,7 @@ void
 init_deco(ModeInfo * mi)
 {
 	decostruct *dp;
-	int         depth = MI_BATCHCOUNT(mi);
+	int         depth = MI_COUNT(mi);
 	int         size = MI_SIZE(mi);
 
 	if (decos == NULL) {
@@ -157,13 +157,13 @@ draw_deco(ModeInfo * mi)
 		MI_CLEARWINDOWCOLOR(mi, dp->bordercolor);
 #ifdef SOLARIS2
 		/*
-		   * if this is not done the first rectangle is sometimes messed up on
-		   * Solaris2 with 24 bit TrueColor (Ultra2)
+		 * if this is not done the first rectangle is sometimes messed up on
+		 * Solaris2 with 24 bit TrueColor (Ultra2)
 		 */
 		XDrawRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-			  0, 0, MI_WIN_WIDTH(mi) / 2 + 1, MI_WIN_HEIGHT(mi) / 2 + 1);
+			  0, 0, MI_WIDTH(mi) / 2 + 1, MI_HEIGHT(mi) / 2 + 1);
 #endif
-		deco(mi, 0, 0, MI_WIN_WIDTH(mi), MI_WIN_HEIGHT(mi), 0);
+		deco(mi, 0, 0, MI_WIDTH(mi), MI_HEIGHT(mi), 0);
 	}
 	if (++dp->time > MI_CYCLES(mi))
 		init_deco(mi);
