@@ -53,14 +53,19 @@ static const char sccsid[] = "@(#)demon.c	4.07 97/11/24 xlockmore";
  "*count: 0 \n" \
  "*cycles: 1000 \n" \
  "*size: -7 \n" \
- "*ncolors: 64 \n"
+ "*ncolors: 64 \n" \
+ "*neighbors: 0 \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
 
+/*-
+ * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
+ */
 extern int  neighbors;
 
 ModeSpecOpt demon_opts =
@@ -413,7 +418,7 @@ init_demon(ModeInfo * mi)
 		}
 	}
 
-	dp->states = MI_BATCHCOUNT(mi);
+	dp->states = MI_COUNT(mi);
 	if (dp->states < -MINSTATES)
 		dp->states = NRAND(-dp->states - MINSTATES + 1) + MINSTATES;
 	else if (dp->states < MINSTATES)
@@ -423,8 +428,8 @@ init_demon(ModeInfo * mi)
 
 	dp->state = 0;
 
-	dp->width = MI_WIN_WIDTH(mi);
-	dp->height = MI_WIN_HEIGHT(mi);
+	dp->width = MI_WIDTH(mi);
+	dp->height = MI_HEIGHT(mi);
 
 	if (dp->neighbors == 6) {
 		int         nccols, ncrows, i;
