@@ -70,12 +70,22 @@ static const char sccsid[] = "@(#)dilemma.c	4.07 97/11/24 xlockmore";
  "*batchcount: -2 \n" \
  "*cycles: 1000 \n" \
  "*size: 0 \n" \
- "*ncolors: 6 \n"
+ "*ncolors: 6 \n" \
+ "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
+#define UNIFORM_COLORS
+#define BRIGHT_COLORS
+#define SMOOTH_COLORS
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+/*-
+ * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
+ */
+extern int  neighbors;
+
 #define DEF_BONUS  "1.85"
 #define DEF_CONSCIOUS  "True"
 
@@ -111,8 +121,6 @@ ModStruct   dilemma_description =
 
 #endif
 
-extern int  neighbors;
-
 /* Better bitmaps needed :) */
 #include "bitmaps/cooperat.xbm"	/* age > 1 then blue, age = 1 then green */
 #include "bitmaps/defect.xbm"	/* age > 1 then red, age = 1 then yellow */
@@ -624,8 +632,8 @@ init_dilemma(ModeInfo * mi)
 			logo[i].bytes_per_line = (icon_width + 7) / 8;
 		}
 	}
-	dp->width = MI_WIN_WIDTH(mi);
-	dp->height = MI_WIN_HEIGHT(mi);
+	dp->width = MI_WIDTH(mi);
+	dp->height = MI_HEIGHT(mi);
 
 	for (i = 0; i < NEIGHBORKINDS; i++) {
 		if (neighbors == plots[i]) {
@@ -775,7 +783,7 @@ init_dilemma(ModeInfo * mi)
 
 	MI_CLEARWINDOW(mi);
 
-	dp->defectors = MI_BATCHCOUNT(mi);
+	dp->defectors = MI_COUNT(mi);
 	if (dp->defectors < -MINDEFECT) {
 		dp->defectors = NRAND(-dp->defectors - MINDEFECT + 1) + MINDEFECT;
 	} else if (dp->defectors < MINDEFECT)
