@@ -723,13 +723,13 @@ init_superquadrics(ModeInfo * mi)
 			return;
 	}
 	sp = &superquadrics[screen];
-	sp->mono = (MI_WIN_IS_MONO(mi) ? 1 : 0);
+	sp->mono = (MI_IS_MONO(mi) ? 1 : 0);
 
 	if ((sp->glx_context = init_GL(mi)) != NULL) {
 
-		InitSuperquadrics(MI_WIN_IS_WIREFRAME(mi), 0,
-			    MI_BATCHCOUNT(mi), MI_CYCLES(mi), spinspeed, sp);
-		ReshapeSuperquadrics(MI_WIN_WIDTH(mi), MI_WIN_HEIGHT(mi));
+		InitSuperquadrics(MI_IS_WIREFRAME(mi), 0,
+				  MI_COUNT(mi), MI_CYCLES(mi), spinspeed, sp);
+		ReshapeSuperquadrics(MI_WIDTH(mi), MI_HEIGHT(mi));
 
 		DisplaySuperquadrics(sp);
 		glFinish();
