@@ -58,9 +58,12 @@ static const char sccsid[] = "@(#)hop.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 10000 \n" \
  "*count: 1000 \n" \
  "*cycles: 2500 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*fullrandom: True \n" \
+ "*verbose: False \n"
 #define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
@@ -200,10 +203,10 @@ init_hop(ModeInfo * mi)
 	}
 	hp = &hops[MI_SCREEN(mi)];
 
-	hp->centerx = MI_WIN_WIDTH(mi) / 2;
-	hp->centery = MI_WIN_HEIGHT(mi) / 2;
+	hp->centerx = MI_WIDTH(mi) / 2;
+	hp->centery = MI_HEIGHT(mi) / 2;
 	/* Make the other operations less common since they are less interesting */
-	if (MI_WIN_IS_FULLRANDOM(mi)) {
+	if (MI_IS_FULLRANDOM(mi)) {
 		hp->op = NRAND(OPS);
 	} else {
 		if (martin)
@@ -247,7 +250,7 @@ init_hop(ModeInfo * mi)
 			else
 				hp->c = 0.0;
 #endif
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "sqrt a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK1:
@@ -259,7 +262,7 @@ init_hop(ModeInfo * mi)
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 40.0;
 #endif
 			hp->b = (LRAND() / MAXRAND) * 0.4;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk1 a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK2:
@@ -274,7 +277,7 @@ init_hop(ModeInfo * mi)
 			hp->c = pow(10.0, (LRAND() / MAXRAND) * 9.0);
 			if (LRAND() & 1)
 				hp->c = -hp->c;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk2 a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK3:
@@ -286,7 +289,7 @@ init_hop(ModeInfo * mi)
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 70.0;
 #endif
 			hp->b = (LRAND() / MAXRAND) * 0.35 + 0.5;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk3 a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK4:
@@ -298,7 +301,7 @@ init_hop(ModeInfo * mi)
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 200.0;
 #endif
 			hp->b = (LRAND() / MAXRAND) * 9.0 + 1.0;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk4 a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK5:
@@ -310,7 +313,7 @@ init_hop(ModeInfo * mi)
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 200.0;
 #endif
 			hp->b = (LRAND() / MAXRAND) * 0.3 + 0.1;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk5 a=%g, b=%g, c=%g\n", hp->a, hp->b, hp->c);
 			break;
 		case EJK6:
@@ -320,7 +323,7 @@ init_hop(ModeInfo * mi)
 			hp->a = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 30.0;
 #endif
 			hp->b = (LRAND() / MAXRAND) + 0.5;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "ejk6 a=%g, b=%g\n", hp->a, hp->b);
 			break;
 		case RR:
@@ -334,7 +337,7 @@ init_hop(ModeInfo * mi)
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * range / 20.0;
 #endif
 			hp->d = (LRAND() / MAXRAND) * 0.9;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "rr a=%g, b=%g, c=%g, d=%g\n",
 					       hp->a, hp->b, hp->c, hp->d);
 			break;
@@ -343,7 +346,7 @@ init_hop(ModeInfo * mi)
 			hp->b = ((LRAND() / MAXRAND) * 2.0 - 1.0) * M_PI;
 			hp->c = ((LRAND() / MAXRAND) * 2.0 - 1.0) * M_PI;
 			hp->d = ((LRAND() / MAXRAND) * 2.0 - 1.0) * M_PI;
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "jong a=%g, b=%g, c=%g, d=%g\n",
 					       hp->a, hp->b, hp->c, hp->d);
 			break;
@@ -353,7 +356,7 @@ init_hop(ModeInfo * mi)
 #else
 			hp->a = M_PI + ((LRAND() / MAXRAND) * 2.0 - 1.0) * 0.7;
 #endif
-			if (MI_WIN_IS_VERBOSE(mi))
+			if (MI_IS_VERBOSE(mi))
 				(void) fprintf(stdout, "sine a=%g\n", hp->a);
 			break;
 	}
@@ -361,7 +364,7 @@ init_hop(ModeInfo * mi)
 		hp->pix = NRAND(MI_NPIXELS(mi));
 	hp->i = hp->j = 0.0;
 	hp->inc = (int) ((LRAND() / MAXRAND) * 200) - 100;
-	hp->bufsize = MI_BATCHCOUNT(mi);
+	hp->bufsize = MI_COUNT(mi);
 
 	if (!hp->pointBuffer)
 		hp->pointBuffer = (XPoint *) malloc(hp->bufsize * sizeof (XPoint));
@@ -476,8 +479,12 @@ draw_hop(ModeInfo * mi)
 	}
 	XDrawPoints(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 		    hp->pointBuffer, hp->bufsize, CoordModeOrigin);
-	if (++hp->count > MI_CYCLES(mi))
+	if (++hp->count > MI_CYCLES(mi)) {
+#ifdef STANDALONE
+		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
+#endif /* STANDALONE */
 		init_hop(mi);
+	}
 }
 
 void
