@@ -163,8 +163,8 @@ init_hyper(ModeInfo * mi)
 	hp = &hypers[MI_SCREEN(mi)];
 
 	hp->redrawing = False;
-	hp->width = MI_WIN_WIDTH(mi);
-	hp->height = MI_WIN_HEIGHT(mi);
+	hp->width = MI_WIDTH(mi);
+	hp->height = MI_HEIGHT(mi);
 	hp->unit_pixels = hp->width < hp->height ? hp->width : hp->height;
 	hp->x_offset = hp->width / 2;
 	hp->y_offset = hp->height / 2;
