@@ -107,7 +107,6 @@ static XPoint *Buf;
 static int  Cur_Pt;
 
 
-/*****************************************************/
 /*****************************************************/
 
 static      DBL
@@ -225,8 +224,8 @@ init_ifs(ModeInfo * mi)
 		return;
 	}
 	Fractal->Speed = 6;
-	Fractal->Width = MI_WIN_WIDTH(mi);
-	Fractal->Height = MI_WIN_HEIGHT(mi);
+	Fractal->Width = MI_WIDTH(mi);
+	Fractal->Height = MI_HEIGHT(mi);
 	Fractal->Cur_Pt = 0;
 	Fractal->Count = 0;
 	Fractal->Lx = (Fractal->Width - 1) / 2;
@@ -267,6 +266,10 @@ init_ifs(ModeInfo * mi)
 
 /***************************************************************/
 
+/* Should be taken care of already... but just in case */
+#if !defined( __GNUC__ ) && !defined(__cplusplus) && !defined(c_plusplus)
+#define inline /* */
+#endif
 static inline void
 Transform(SIMI * Simi, F_PT xo, F_PT yo, F_PT * x, F_PT * y)
 {
