@@ -27,7 +27,7 @@ static const char sccsid[] = "@(#)julia.c	4.07 97/11/24 xlockmore";
  * 02-Dec-95: snagged boilerplate from hop.c
  *           used ifs {w0 = sqrt(x-c), w1 = -sqrt(x-c)} with random iteration 
  *           to plot the julia set, and sinusoidially varied parameter for set 
- *	     and plotted parameter with a circle.
+ *           and plotted parameter with a circle.
  */
 
 /*-
@@ -46,9 +46,11 @@ static const char sccsid[] = "@(#)julia.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 10000 \n" \
  "*count: 1000 \n" \
  "*cycles: 20 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*mouse: False \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
@@ -66,8 +68,6 @@ ModStruct   julia_description =
 
 #endif
 
-extern Bool mouse;
-
 #define numpoints ((0x2<<jp->depth)-1)
 
 typedef struct {
@@ -110,7 +110,7 @@ apply(juliastruct * jp, register double xr, register double xi, int d)
 		xi -= jp->ci;
 		xr -= jp->cr;
 
-/* Avoid atan2: DOMAIN error message */
+		/* Avoid atan2: DOMAIN error message */
 		theta = (xi == 0.0 && xr == 0.0) ? 0.0 : atan2(xi, xr) / 2.0;
 
 		/*r = pow(xi * xi + xr * xr, 0.25); */
@@ -128,7 +128,7 @@ apply(juliastruct * jp, register double xr, register double xi, int d)
 static void
 incr(ModeInfo * mi, juliastruct * jp)
 {
-	Bool        track_p = mouse;
+	Bool        track_p = MI_IS_MOUSE(mi);
 	int         cx, cy;
 
 	if (track_p) {
@@ -139,8 +139,8 @@ incr(ModeInfo * mi, juliastruct * jp)
 		(void) XQueryPointer(MI_DISPLAY(mi), MI_WINDOW(mi),
 				     &r, &c, &rx, &ry, &cx, &cy, &m);
 		if (cx <= 0 || cy <= 0 ||
-		    cx >= MI_WIN_WIDTH(mi) - jp->circsize - 1 ||
-		    cy >= MI_WIN_HEIGHT(mi) - jp->circsize - 1)
+		    cx >= MI_WIDTH(mi) - jp->circsize - 1 ||
+		    cy >= MI_HEIGHT(mi) - jp->circsize - 1)
 			track_p = False;
 	}
 	if (track_p) {
@@ -173,18 +173,14 @@ init_julia(ModeInfo * mi)
 	}
 	jp = &julias[MI_SCREEN(mi)];
 
-#ifdef STANDALONE
-	mouse = get_boolean_resource("mouse", "Boolean");
-#endif /* !STANDALONE */
+	jp->centerx = MI_WIDTH(mi) / 2;
+	jp->centery = MI_HEIGHT(mi) / 2;
 
-	jp->centerx = MI_WIN_WIDTH(mi) / 2;
-	jp->centery = MI_WIN_HEIGHT(mi) / 2;
-
-	jp->depth = MI_BATCHCOUNT(mi);
+	jp->depth = MI_COUNT(mi);
 	if (jp->depth > 10)
 		jp->depth = 10;
 
-	if (mouse && !jp->cursor) {	/* Create an invisible cursor */
+	if (MI_IS_MOUSE(mi) && !jp->cursor) {	/* Create an invisible cursor */
 		Pixmap      bit;
 		XColor      black;
 
@@ -382,6 +378,7 @@ refresh_julia(ModeInfo * mi)
 {
 	juliastruct *jp = &julias[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	jp->redrawing = 1;
 	jp->redrawpos = 0;
 }
