@@ -40,7 +40,8 @@ static const char sccsid[] = "@(#)kaleid.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 20000 \n" \
  "*cycles: 700 \n" \
  "*ncolors: 200 \n"
-#define SPREAD_COLORS
+#define UNIFORM_COLORS
+#define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -90,8 +91,8 @@ init_kaleid(ModeInfo * mi)
 	}
 	kp = &kaleids[MI_SCREEN(mi)];
 
-	kp->width = MI_WIN_WIDTH(mi);
-	kp->height = MI_WIN_HEIGHT(mi);
+	kp->width = MI_WIDTH(mi);
+	kp->height = MI_HEIGHT(mi);
 	if (kp->width < 2)
 		kp->width = 2;
 	if (kp->height < 2)
