@@ -119,6 +119,7 @@ typedef struct lisa_struct {
 	double      pistep, phi, theta;
 	XPoint      center, *lastpoint;
 	lisafuncs  *function[LISAMAXFUNCS];
+	int         linewidth;
 } lisas;
 
 typedef struct lisacontext_struct {
@@ -281,6 +282,8 @@ drawlisa(ModeInfo * mi, lisas * loop)
 	for (pctr = 0; pctr < loop->nsteps; pctr++) {
 
 #if defined DRAWLINES
+		XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi), loop->linewidth,
+				   LineSolid, CapProjecting, JoinMiter);
 		/* erase the last cycle's point */
 		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
 		XDrawLine(MI_DISPLAY(mi), MI_WINDOW(mi), \
@@ -296,6 +299,8 @@ drawlisa(ModeInfo * mi, lisas * loop)
 			  MI_GC(mi), np[pctr].x, np[pctr].y, \
 			  np[(pctr + 1) % loop->nsteps].x, \
 			  np[(pctr + 1) % loop->nsteps].y);
+		XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi), 1,
+				   LineSolid, CapProjecting, JoinMiter);
 #else
 		/* erase the last cycle's point */
 		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
@@ -374,6 +379,18 @@ initlisa(ModeInfo * mi, lisas * loop)
 		lp[pctr].x = (int) ceil(xsum);
 		lp[pctr].y = (int) ceil(ysum);
 	}
+#if defined DRAWLINES
+	{
+		loop->linewidth = -8;	/* #### make this a resource */
+
+		if (loop->linewidth == 0)
+			loop->linewidth = 1;
+		if (loop->linewidth < 0)
+			loop->linewidth = NRAND(-loop->linewidth) + 1;
+		XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi), loop->linewidth,
+				   LineSolid, CapProjecting, JoinMiter);
+	}
+#endif
 	for (pctr = 0; pctr < loop->nsteps; pctr++) {
 		/* Set the color */
 		lisasetcolor();
@@ -387,6 +404,11 @@ initlisa(ModeInfo * mi, lisas * loop)
 			   lp[pctr].x, lp[pctr].y);
 #endif
 	}
+#if defined DRAWLINES
+	XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi), 1,
+			   LineSolid, CapProjecting, JoinMiter);
+#endif
+
 }
 
 void
@@ -395,6 +417,7 @@ refresh_lisa(ModeInfo * mi)
 	lisacons   *lc = &Lisa[MI_SCREEN(mi)];
 	int         lctr;
 
+	MI_CLEARWINDOW(mi);
 	for (lctr = 0; lctr < lc->nlisajous; lctr++) {
 		drawlisa(mi, &lc->lisajous[lctr]);
 	}
@@ -430,10 +453,10 @@ init_lisa(ModeInfo * mi)
 			return;
 	}
 	lc = &Lisa[MI_SCREEN(mi)];
-	lc->width = MI_WIN_WIDTH(mi);
-	lc->height = MI_WIN_HEIGHT(mi);
+	lc->width = MI_WIDTH(mi);
+	lc->height = MI_HEIGHT(mi);
 	lc->loopcount = 0;
-	lc->nlisajous = MI_BATCHCOUNT(mi);
+	lc->nlisajous = MI_COUNT(mi);
 	if (lc->nlisajous <= 0)
 		lc->nlisajous = 1;
 
