@@ -56,8 +56,9 @@ static const char sccsid[] = "@(#)loop.c	4.07 97/11/24 xlockmore";
  "*cycles: 1600 \n" \
  "*size: -12 \n" \
  "*ncolors: 15 \n"
-#define SPREAD_COLORS
+#define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
@@ -472,8 +473,8 @@ init_loop(ModeInfo * mi)
 	free_list(lp);
 	lp->generation = 0;
 
-	lp->width = MI_WIN_WIDTH(mi);
-	lp->height = MI_WIN_HEIGHT(mi);
+	lp->width = MI_WIDTH(mi);
+	lp->height = MI_HEIGHT(mi);
 
 	if (size < -MINSIZE)
 		lp->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(lp->width, lp->height) /
@@ -592,6 +593,7 @@ refresh_loop(ModeInfo * mi)
 {
 	loopstruct *lp = &loops[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	lp->redrawing = 1;
 	lp->redrawpos = lp->bncols + 1;
 }
