@@ -193,7 +193,7 @@ init_mandelbrot(ModeInfo * mi)
 	mp = &mandels[MI_SCREEN(mi)];
 
 
-	power = MI_BATCHCOUNT(mi);
+	power = MI_COUNT(mi);
 	if (power < -MINPOWER) {
 		int         temp;
 
@@ -211,6 +211,8 @@ init_mandelbrot(ModeInfo * mi)
 
 	MI_CLEARWINDOW(mi);
 
+
+#ifndef STANDALONE
 	mp->fixed_colormap = !setupColormap(mi,
 		&(mp->ncolors), &truecolor, &redmask, &greenmask, &bluemask);
 	if (!mp->fixed_colormap) {
@@ -240,6 +242,7 @@ init_mandelbrot(ModeInfo * mi)
 						   MI_VISUAL(mi), AllocAll);
 		mp->usable_colors = mp->ncolors - preserve;
 	}
+#endif /* !STANDALONE */
 }
 
 static int
@@ -285,9 +288,10 @@ draw_mandelbrot(ModeInfo * mi)
 	int         j, k;
 
 	log_top = log((float) top);
-	screen_width = MI_WIN_WIDTH(mi);
-	screen_height = ((MI_WIN_HEIGHT(mi) + 1) >> 1) << 1;	/* screen_height even */
+	screen_width = MI_WIDTH(mi);
+	screen_height = ((MI_HEIGHT(mi) + 1) >> 1) << 1;	/* screen_height even */
 
+#ifndef STANDALONE
 	if (mp->counter % 5 == 0) {
 		/* advance "drawing" color */
 		mp->cur_color = (mp->cur_color + 1) % mp->ncolors;
@@ -342,13 +346,14 @@ draw_mandelbrot(ModeInfo * mi)
 			}
 			/* make the entire tube move forward */
 			XStoreColors(display, mp->cmap, mp->colors, mp->ncolors);
-			setColormap(display, window, mp->cmap, MI_WIN_IS_INWINDOW(mi));
+			setColormap(display, window, mp->cmap, MI_IS_INWINDOW(mi));
 		}
 	}
+#endif /* !STANDALONE */
 	if (mp->column >= 3 * screen_width / 2) {
 		/* reset to left edge of screen, bump power */
 		mp->column = 0;
-		if (MI_BATCHCOUNT(mi) >= -MINPOWER) {	/* Then do not randomize */
+		if (MI_COUNT(mi) >= -MINPOWER) {	/* Then do not randomize */
 			mp->power += increment;
 			/* round to third digit after decimal, in case of floating point
 			   inaccuracy.  Assumption: no one wants to increment this by
@@ -359,7 +364,7 @@ draw_mandelbrot(ModeInfo * mi)
 			int         temp;
 
 			do {
-				temp = NRAND(-MI_BATCHCOUNT(mi) - MINPOWER + 1) + MINPOWER;
+				temp = NRAND(-MI_COUNT(mi) - MINPOWER + 1) + MINPOWER;
 			} while (temp == mp->power);
 			mp->power = temp;
 		}
@@ -404,6 +409,7 @@ draw_mandelbrot(ModeInfo * mi)
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		else {
 			color = (unsigned int) (MI_NPIXELS(mi) * log((float) result) / log_top);
+#ifndef STANDALONE
 			if (!mp->fixed_colormap && mp->usable_colors > 2) {
 				while (color == MI_WHITE_PIXEL(mi) ||
 				       color == MI_BLACK_PIXEL(mi) ||
@@ -414,6 +420,7 @@ draw_mandelbrot(ModeInfo * mi)
 				XSetForeground(display, gc, color);
 			} else
 				XSetForeground(display, gc, MI_PIXEL(mi, color));
+#endif /* !STANDALONE */
 		}
 		/* take advantage of vertical symmetry */
 		XDrawPoint(display, window, gc, mp->column, h);
