@@ -33,7 +33,9 @@ static const char sccsid[] = "@(#)mountain.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 1000 \n" \
  "*count: 30 \n" \
  "*cycles: 4000 \n" \
- "*ncolors: 64 \n"
+ "*ncolors: 64 \n" \
+ "*wireframe: False \n"
+#define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -125,11 +127,16 @@ drawamountain(ModeInfo * mi)
 		XSetForeground(display, gc, MI_PIXEL(mi, c));
 	else
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
-	XFillPolygon(display, window, gc, p, 4, Complex, CoordModeOrigin);
 
-	if (!mp->pixelmode) {
-		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+	if (MI_IS_WIREFRAME(mi)) {
 		XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+	} else {
+		XFillPolygon(display, window, gc, p, 4, Complex, CoordModeOrigin);
+
+		if (!mp->pixelmode) {
+			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+		}
 	}
 	mp->x++;
 	if (mp->x == WORLDWIDTH - 1) {
@@ -153,8 +160,8 @@ init_mountain(ModeInfo * mi)
 			return;
 	}
 	mp = &mountains[MI_SCREEN(mi)];
-	mp->width = MI_WIN_WIDTH(mi);
-	mp->height = MI_WIN_HEIGHT(mi);
+	mp->width = MI_WIDTH(mi);
+	mp->height = MI_HEIGHT(mi);
 	mp->pixelmode = (mp->width + mp->height < 200);
 	mp->stage = 0;
 	mp->time = 0;
@@ -173,7 +180,7 @@ init_mountain(ModeInfo * mi)
 		for (x = 0; x < WORLDWIDTH; x++)
 			mp->h[x][y] = 0;
 
-	j = MI_BATCHCOUNT(mi);
+	j = MI_COUNT(mi);
 	if (j < 0)
 		j = NRAND(-j) + 1;
 	for (i = 0; i < j; i++)
@@ -225,7 +232,8 @@ release_mountain(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 			mountainstruct *mp = &mountains[screen];
 
-			XFreeGC(MI_DISPLAY(mi), mp->stippled_GC);
+			if (mp->stippled_GC)
+				XFreeGC(MI_DISPLAY(mi), mp->stippled_GC);
 		}
 		(void) free((void *) mountains);
 		mountains = NULL;
@@ -237,6 +245,7 @@ refresh_mountain(ModeInfo * mi)
 {
 	mountainstruct *mp = &mountains[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	mp->x = 0;
 	mp->y = 0;
 }
