@@ -169,8 +169,8 @@ init_munch(ModeInfo * mi)
 			     (unsigned long) 0, (XGCValues *) NULL)) == None)
 			return;
 	}
-	mp->width = MI_WIN_WIDTH(mi);
-	mp->height = MI_WIN_HEIGHT(mi);
+	mp->width = MI_WIDTH(mi);
+	mp->height = MI_HEIGHT(mi);
 
 	/* We need a square; limit on screen size? */
 	/* we want a power of 2 for the width or the munch doesn't fill up. */
@@ -180,7 +180,7 @@ init_munch(ModeInfo * mi)
 	XSetFunction(display, mp->gc, GXxor);
 
 	mp->logminwidth = MI_CYCLES(mi);
-	if (mp->logminwidth < 2 || MI_WIN_IS_ICONIC(mi))
+	if (mp->logminwidth < 2 || MI_IS_ICONIC(mi))
 		mp->logminwidth = 2;
 
 	if (mp->logmaxwidth < mp->logminwidth)
