@@ -54,8 +54,15 @@ static const char sccsid[] = "@(#)nose.c	4.07 97/11/24 xlockmore";
 #define HACK_DRAW draw_nose
 #define nose_opts xlockmore_opts
 #define DEFAULTS "*delay: 100000 \n" \
- "*ncolors: 64 \n"
+ "*ncolors: 64 \n" \
+ "*font: \n" \
+ "*text: \n" \
+ "*filename: \n" \
+ "*fortunefile: \n" \
+ "*program: \n"
+#define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
@@ -663,8 +670,8 @@ init_nose(ModeInfo * mi)
 	}
 	np = &noses[MI_SCREEN(mi)];
 
-	np->width = MI_WIN_WIDTH(mi) + 2;
-	np->height = MI_WIN_HEIGHT(mi) + 2;
+	np->width = MI_WIDTH(mi) + 2;
+	np->height = MI_HEIGHT(mi) + 2;
 	np->tinymode = (np->width + np->height < 4 * PIXMAP_SIZE);
 	np->xs = PIXMAP_SIZE;
 	np->ys = PIXMAP_SIZE;
@@ -765,5 +772,5 @@ release_nose(ModeInfo * mi)
 void
 refresh_nose(ModeInfo * mi)
 {
-	/* Do nothing, it will refresh by itself */
+	MI_CLEARWINDOW(mi);
 }
