@@ -38,7 +38,7 @@ static const char sccsid[] = "@(#)random.c	4.07 97/11/24 xlockmore";
 #define HACK_INIT init_random
 #define HACK_DRAW draw_random
 #define random_opts xlockmore_opts
-#define DEFAULTS ""
+#define DEFAULTS "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -100,13 +100,14 @@ ModStruct   random_description =
 
 #define GC_SAVE_VALUES (GCFunction|GCLineWidth|GCLineStyle|GCCapStyle|GCJoinStyle|GCGraphicsExposures|GCFont|GCSubwindowMode)
 
+extern int  startscreen;
 extern int  delay;
-extern int  batchcount;
+extern int  count;
 extern int  cycles;
 extern int  size;
 extern int  ncolors;
 extern float saturation;
-extern char *imagefile;
+extern char *bitmap;
 
 #define MAXMODECHARS 14
 
@@ -200,9 +201,9 @@ static char automata_modes[][MAXMODECHARS] =
 
 static char fractal_modes[][MAXMODECHARS] =
 {
-	"coral", "drift", "flame", "forest", "julia", "hop",
-	"ifs", "lightning", "mandelbrot", "mountain",
-	"sierpinski", "strange", "triangle", "turtle", "vines"
+	"coral", "discrete", "drift", "flame", "flow", "forest",
+	"julia", "hop", "ifs", "lightning", "mandelbrot", "mountain",
+	"sierpinski", "strange", "thornbird", "triangle", "turtle", "vines"
 };
 
 #define NUMFRACTAL (sizeof (fractal_modes) / sizeof (fractal_modes[0]))
@@ -428,7 +429,7 @@ parsemodelist(ModeInfo * mi)
 			modes[i] = i;
 		nmodes = i;
 	}
-	if (MI_WIN_IS_DEBUG(mi)) {
+	if (MI_IS_DEBUG(mi)) {
 		(void) fprintf(stderr, "%d mode%s: ", nmodes, ((nmodes == 1) ? "" : "s"));
 		for (i = 0; i < nmodes; i++)
 			(void) fprintf(stderr, "%d ", modes[i]);
@@ -448,20 +449,20 @@ setMode(ModeInfo * mi, int newmode)
 
 /* FIX THIS GLOBAL ACCESS */
 	delay = MI_DELAY(mi) = LockProcs[currentmode].def_delay;
-	batchcount = MI_BATCHCOUNT(mi) = LockProcs[currentmode].def_batchcount;
+	count = MI_COUNT(mi) = LockProcs[currentmode].def_count;
 	cycles = MI_CYCLES(mi) = LockProcs[currentmode].def_cycles;
 	size = MI_SIZE(mi) = LockProcs[currentmode].def_size;
 	ncolors = MI_NCOLORS(mi) = LockProcs[currentmode].def_ncolors;
 	saturation = MI_SATURATION(mi) = LockProcs[currentmode].def_saturation;
-	imagefile = MI_IMAGEFILE(mi) = LockProcs[currentmode].def_imagefile;
+	bitmap = MI_BITMAP(mi) = LockProcs[currentmode].def_bitmap;
 
-	for (i = 0; i < MI_NUM_SCREENS(mi); i++) {
+	for (i = startscreen; i < MI_NUM_SCREENS(mi); i++) {
 
 		XChangeGC(MI_DISPLAY(mi), MI_GC(mi), GC_SAVE_VALUES,
 			  &(rp->gcvs));		/* Not sure if this is right for multiscreens */
 		randoms[i].fix = True;
 	}
-	if (MI_WIN_IS_VERBOSE(mi))
+	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stderr, "mode: %s\n", LockProcs[currentmode].cmdline_arg);
 }
 
@@ -481,7 +482,7 @@ init_random(ModeInfo * mi)
 	if (currentmode < 0) {
 		parsemodelist(mi);
 
-		for (i = 0; i < MI_NUM_SCREENS(mi); i++) {
+		for (i = startscreen; i < MI_NUM_SCREENS(mi); i++) {
 			(void) XGetGCValues(MI_DISPLAY(mi), MI_GC(mi),
 					    GC_SAVE_VALUES, &(rp->gcvs));
 		}
@@ -492,8 +493,8 @@ init_random(ModeInfo * mi)
 	}
 	if (rp->fix) {
 		fixColormap(MI_DISPLAY(mi), MI_WINDOW(mi), MI_SCREEN(mi), MI_NCOLORS(mi),
-		MI_SATURATION(mi), MI_WIN_IS_MONO(mi), MI_WIN_IS_INSTALL(mi),
-			    MI_WIN_IS_INROOT(mi), MI_WIN_IS_INWINDOW(mi), MI_WIN_IS_VERBOSE(mi));
+			MI_SATURATION(mi), MI_IS_MONO(mi), MI_IS_INSTALL(mi),
+		    MI_IS_INROOT(mi), MI_IS_INWINDOW(mi), MI_IS_VERBOSE(mi));
 		rp->fix = False;
 	}
 	call_init_hook(&LockProcs[currentmode], mi);
@@ -509,10 +510,10 @@ draw_random(ModeInfo * mi)
 	int         has_run = (duration == 0) ? 0 : (int) (now - starttime);
 	static int  do_init = 0;
 
-	if ((scrn == 0) && do_init) {
+	if ((scrn == startscreen) && do_init) {
 		do_init = 0;
 	}
-	if ((scrn == 0) && (change_now || (has_run > duration))) {
+	if ((scrn == startscreen) && (change_now || (has_run > duration))) {
 		newmode = pickMode();
 
 		MI_CLEARWINDOW(mi);
@@ -524,8 +525,8 @@ draw_random(ModeInfo * mi)
 	}
 	if (rp->fix) {
 		fixColormap(MI_DISPLAY(mi), MI_WINDOW(mi), MI_SCREEN(mi), MI_NCOLORS(mi),
-		MI_SATURATION(mi), MI_WIN_IS_MONO(mi), MI_WIN_IS_INSTALL(mi),
-			    MI_WIN_IS_INROOT(mi), MI_WIN_IS_INWINDOW(mi), MI_WIN_IS_VERBOSE(mi));
+			MI_SATURATION(mi), MI_IS_MONO(mi), MI_IS_INSTALL(mi),
+		    MI_IS_INROOT(mi), MI_IS_INWINDOW(mi), MI_IS_VERBOSE(mi));
 		rp->fix = False;
 	}
 	if (do_init) {
@@ -543,7 +544,7 @@ refresh_random(ModeInfo * mi)
 void
 change_random(ModeInfo * mi)
 {
-	if (MI_SCREEN(mi) == 0)
+	if (MI_SCREEN(mi) == startscreen)
 		change_now = True;	/* force a change on next draw callback */
 
 	draw_random(mi);
