@@ -131,8 +131,8 @@ init_spiral(ModeInfo * mi)
 	}
 	sp = &spirals[MI_SCREEN(mi)];
 
-	sp->width = MI_WIN_WIDTH(mi);
-	sp->height = MI_WIN_HEIGHT(mi);
+	sp->width = MI_WIDTH(mi);
+	sp->height = MI_HEIGHT(mi);
 
 	MI_CLEARWINDOW(mi);
 
@@ -176,7 +176,7 @@ init_spiral(ModeInfo * mi)
 	sp->traildots[sp->inc].hr = sp->radius;
 	sp->inc++;
 
-	sp->dots = MI_BATCHCOUNT(mi);
+	sp->dots = MI_COUNT(mi);
 	if (sp->dots < -MINDOTS)
 		sp->dots = NRAND(sp->dots - MINDOTS + 1) + MINDOTS;
 	/* Absolute minimum */
@@ -304,6 +304,7 @@ refresh_spiral(ModeInfo * mi)
 {
 	spiralstruct *sp = &spirals[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	sp->redrawing = 1;
 	sp->redrawpos = 0;
 }
