@@ -243,8 +243,8 @@ init_turtle(ModeInfo * mi)
 	}
 	tp = &turtles[MI_SCREEN(mi)];
 
-	tp->width = MI_WIN_WIDTH(mi);
-	tp->height = MI_WIN_HEIGHT(mi);
+	tp->width = MI_WIDTH(mi);
+	tp->height = MI_HEIGHT(mi);
 	tp->min = MIN(tp->width, tp->height);
 	tp->maxlevel = 0;
 	i = tp->min;
