@@ -66,12 +66,19 @@ static const char sccsid[] = "@(#)wire.c	4.07 97/11/24 xlockmore";
  "*count: 1000 \n" \
  "*cycles: 150 \n" \
  "*size: -8 \n" \
- "*ncolors: 64 \n"
+ "*ncolors: 64 \n" \
+ "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+/*-
+ * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
+ */
+extern int  neighbors;
+
 ModeSpecOpt wire_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -84,8 +91,6 @@ ModStruct   wire_description =
 
 #endif
 
-extern int  neighbors;
-
 #define WIREBITS(n,w,h)\
   wp->pixmaps[wp->init_bits++]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1)
@@ -717,8 +722,8 @@ init_wire(ModeInfo * mi)
 	}
 	free_list(wp);
 	wp->generation = 0;
-	wp->width = MI_WIN_WIDTH(mi);
-	wp->height = MI_WIN_HEIGHT(mi);
+	wp->width = MI_WIDTH(mi);
+	wp->height = MI_HEIGHT(mi);
 
 	for (n = 0; n < NEIGHBORKINDS; n++) {
 		if (neighbors == plots[n]) {
@@ -847,7 +852,7 @@ init_wire(ModeInfo * mi)
 	wp->newcells = (unsigned char *)
 		calloc(wp->bncols * wp->bnrows, sizeof (unsigned char));
 
-	n = MI_BATCHCOUNT(mi);
+	n = MI_COUNT(mi);
 	i = (1 + (wp->neighbors == 6)) * wp->ncols * wp->nrows / 4;
 	if (n < -MINWIRES && i > MINWIRES) {
 		n = NRAND(MIN(-n, i) - MINWIRES + 1) + MINWIRES;
@@ -928,6 +933,7 @@ refresh_wire(ModeInfo * mi)
 {
 	circuitstruct *wp = &circuits[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	wp->redrawing = 1;
 	wp->redrawpos = 2 * wp->ncols + 2;
 }
