@@ -28,7 +28,7 @@ static const char sccsid[] = "@(#)mode.c	4.07 97/11/24 xlockmore";
 /* -------------------------------------------------------------------- */
 
 /*-
- * Mode options: If batchcount, cycles, or size options are set to 1 ...
+ * Mode options: If count, cycles, or size options are set to 1 ...
  * they are probably not used by the mode.
  */
 
@@ -62,7 +62,7 @@ LockStruct  LockProcs[] =
 	 "Shows bouncing footballs", 0, NULL},
 	{"braid", init_braid, draw_braid, release_braid,
 	 refresh_braid, init_braid, NULL, &braid_opts,
-	 1000, 15, 100, 1, 64, 1.0, "",
+	 1000, 15, 100, -7, 64, 1.0, "",
 	 "Shows random braids and knots", 0, NULL},
 	{"bug", init_bug, draw_bug, release_bug,
 	 refresh_bug, init_bug, NULL, &bug_opts,
@@ -116,6 +116,10 @@ LockStruct  LockProcs[] =
 	 refresh_dilemma, init_dilemma, NULL, &dilemma_opts,
 	 200000, -2, 1000, 0, 64, 1.0, "",
 	 "Shows Lloyd's Prisoner's Dilemma simulation", 0, NULL},
+	{"discrete", init_discrete, draw_discrete, release_discrete,
+	 refresh_discrete, init_discrete, NULL, &discrete_opts,
+	 1000, 4096, 2500, 1, 64, 1.0, "",
+	 "Shows various discrete maps", 0, NULL},
 	{"drift", init_drift, draw_drift, release_drift,
 	 refresh_drift, init_drift, NULL, &drift_opts,
 	 10000, 30, 1, 1, 64, 1.0, "",
@@ -136,6 +140,10 @@ LockStruct  LockProcs[] =
 	 refresh_flame, init_flame, NULL, &flame_opts,
 	 750000, 20, 10000, 1, 64, 1.0, "",
 	 "Shows cosmic flame fractals", 0, NULL},
+	{"flow", init_flow, draw_flow, release_flow,
+	 refresh_flow, init_flow, NULL, &flow_opts,
+	 1000, 1024, 3000, 1, 64, 1.0, "",
+	 "Shows dynamic strange attractors", 0, NULL},
 	{"forest", init_forest, draw_forest, release_forest,
 	 refresh_forest, init_forest, NULL, &forest_opts,
 	 400000, 100, 200, 1, 64, 1.0, "",
@@ -150,6 +158,10 @@ LockStruct  LockProcs[] =
 	 1000, 1, 2, 1, 64, 1.0, "",
 	 "Shows GL's gears", 0, NULL},
 #endif
+	{"goop", init_goop, draw_goop, release_goop,
+	 init_goop, init_goop, NULL, &goop_opts,
+	 10000, -12, 1, 1, 64, 1.0, "",
+	 "Shows goop from a lava lamp", 0, NULL},
 	{"grav", init_grav, draw_grav, release_grav,
 	 refresh_grav, init_grav, NULL, &grav_opts,
 	 10000, -12, 1, 1, 64, 1.0, "",
@@ -223,7 +235,7 @@ LockStruct  LockProcs[] =
 	 25000, -8, 20000, 1, 64, 1.0, "",
 	 "Shows mandelbrot sets", 0, NULL},
 	{"marquee", init_marquee, draw_marquee, release_marquee,
-	 refresh_marquee, init_marquee, NULL, &marquee_opts,
+	 init_marquee, init_marquee, NULL, &marquee_opts,
 	 100000, 1, 1, 1, 64, 1.0, "",
 	 "Shows messages", 0, NULL},
 	{"maze", init_maze, draw_maze, release_maze,
@@ -293,7 +305,7 @@ LockStruct  LockProcs[] =
 	 "Shows a rolling ball", 0, NULL},
 	{"rotor", init_rotor, draw_rotor, release_rotor,
 	 refresh_rotor, init_rotor, NULL, &rotor_opts,
-	 10000, 4, 20, 1, 64, 0.4, "",
+	 10000, 4, 20, -6, 64, 0.4, "",
 	 "Shows Tom's Roto-Rooter", 0, NULL},
 #ifdef USE_GL
 	{"rubik", init_rubik, draw_rubik, release_rubik,
@@ -357,6 +369,10 @@ LockStruct  LockProcs[] =
 	 refresh_swirl, init_swirl, NULL, &swirl_opts,
 	 5000, 5, 1, 1, 64, 1.0, "",
 	 "Shows animated swirling patterns", 0, NULL},
+	{"thornbird", init_thornbird, draw_thornbird, release_thornbird,
+	 refresh_thornbird, NULL, NULL, &thornbird_opts,
+	 1000, 800, 16, 1, 64, 1.0, "",
+	 "Shows an animated bird in a thorn bush fractal map", 0, NULL},
 	{"triangle", init_triangle, draw_triangle, release_triangle,
 	 refresh_triangle, init_triangle, NULL, &triangle_opts,
 	 10000, 1, 1, 1, 64, 1.0, "",
@@ -640,12 +656,12 @@ LoadModules(char *path)
 				}
 				new->lock->msopt = desc->msopt;
 				new->lock->def_delay = desc->def_delay;
-				new->lock->def_batchcount = desc->def_batchcount;
+				new->lock->def_count = desc->def_count;
 				new->lock->def_cycles = desc->def_cycles;
 				new->lock->def_size = desc->def_size;
 				new->lock->def_ncolors = desc->def_ncolors;
 				new->lock->def_saturation = desc->def_saturation;
-				new->lock->def_imagefile = desc->def_imagefile;
+				new->lock->def_bitmap = desc->def_bitmap;
 				new->lock->desc = desc->desc;
 				new->lock->flags = desc->flags;
 				new->lock->userdata = desc->userdata;
@@ -738,7 +754,7 @@ set_window_title(ModeInfo * mi)
 		XSetWMName(MI_DISPLAY(mi), MI_WINDOW(mi), &prop);
 		XFree((caddr_t) prop.value);
 	}
-	if (MI_WIN_IS_ICONIC(mi)) {
+	if (MI_IS_ICONIC(mi)) {
 		extern void modeDescription(ModeInfo * mi);
 
 		modeDescription(mi);
@@ -809,7 +825,7 @@ call_init_hook(LockStruct * ls, ModeInfo * mi)
 	ls->init_hook(mi);
 
 	ls->flags |= LS_FLAG_INITED;
-	MI_WIN_SET_FLAG_STATE(mi, WI_FLAG_JUST_INITTED, True);
+	MI_SET_FLAG_STATE(mi, WI_FLAG_JUST_INITTED, True);
 
 	last_initted_mode = ls;
 }
@@ -837,7 +853,7 @@ call_callback_hook(LockStruct * ls, ModeInfo * mi)
 
 	ls->callback_hook(mi);
 
-	MI_WIN_SET_FLAG_STATE(mi, WI_FLAG_JUST_INITTED, False);
+	MI_SET_FLAG_STATE(mi, WI_FLAG_JUST_INITTED, False);
 }
 
 /* -------------------------------------------------------------------- */
@@ -848,7 +864,7 @@ call_callback_hook(LockStruct * ls, ModeInfo * mi)
  *      hook again.
  */
 
-#define JUST_INITTED(mi)	(MI_WIN_FLAG_IS_SET(mi, WI_FLAG_JUST_INITTED))
+#define JUST_INITTED(mi)	(MI_FLAG_IS_SET(mi, WI_FLAG_JUST_INITTED))
 
 void
 call_refresh_hook(LockStruct * ls, ModeInfo * mi)
