@@ -594,6 +594,10 @@ gpass()
 			buf[0] = '\0';
 			if ((fgets(buf, sizeof buf, fp) == NULL) ||
 			    (!(strlen(buf) == CPASSLENGTH - 1 ||
+#if defined(HAVE_KRB4) || defined(HAVE_KRB5)
+			       (((strlen(buf) == 1) || strlen(buf) == 2)
+				&& buf[0] == '*') ||
+#endif
 			       (strlen(buf) == CPASSLENGTH && buf[CPASSLENGTH - 1] == '\n')))) {
 				(void) fprintf(stderr, "%s: %s crypted password %s\n", xlockrc,
 				       buf[0] == '\0' ? "null" : "bad", buf);
@@ -1159,6 +1163,9 @@ checkPasswd(char *buffer)
 #ifdef DCE_PASSWD
 #include <pthread.h>
 #include <dce/sec_login.h>
+#ifdef AIXV3
+#include <userpw.h>
+#endif
 
 static void
 initDCE(void)
@@ -1167,6 +1174,11 @@ initDCE(void)
 	error_status_t error_status;
 	boolean32   valid;
 	struct passwd *pwd;
+
+#ifdef AIXV3
+	struct userpw *userpwd;
+
+#endif
 	char       *buf;
 
 	/* test to see if this user exists on the network registry */
@@ -1207,6 +1219,16 @@ initDCE(void)
 		usernet = 1;
 
 	if (allowroot) {
+#ifdef AIXV3
+		userpwd = getuserpw("root");
+		(void) strcpy(rootpass, userpwd->upw_passwd);
+		if (!(strcmp(rootpass, ""))) {
+			(void) fprintf(stderr, "%s: could not get root password\n", ProgramName);
+			allowroot = 0;
+		} else {
+			rootnet = 0;
+		}
+#else
 		valid = sec_login_setup_identity((unsigned_char_p_t) ROOT,
 			  sec_login_no_flags, &login_context, &error_status);
 		if (!valid) {
@@ -1240,6 +1262,7 @@ initDCE(void)
 			(void) strcpy(rootpass, pwd->pw_passwd);
 		} else
 			rootnet = 1;
+#endif
 	}
 	pthread_lock_global_np();
 }
