@@ -13,6 +13,8 @@ static const char sccsid[] = "@(#)resource.c	4.07 97/11/24 xlockmore";
  * Revision History:
  *
  * Changes maintained by David Bagley <bagleyd@bigfoot.com>
+ * 01-May-97: Matthew Rench <mdrench@mtu.edu>
+ *            Added DPMS options.
  * 01-Apr-97: Tom Schmidt <tschmidt@micron.com>
  *            Fixed memory leak.  Made -visual option a hacker mode for now.
  * 20-Mar-97: Tom Schmidt <tschmidt@micron.com>
@@ -136,7 +138,7 @@ static int  descr();
 #endif
 #endif
 #define DEF_DELAY	"200000"	/* microseconds between batches */
-#define DEF_BATCHCOUNT	"100"	/* vectors (or whatever) per batch */
+#define DEF_COUNT	"100"	/* vectors (or whatever) per batch */
 #define DEF_CYCLES	"1000"	/* timeout in cycles for a batch */
 #define DEF_SIZE	"0"	/* size, default if 0 */
 #define DEF_NCOLORS	"64"	/* maximum number of colors */
@@ -151,7 +153,7 @@ static int  descr();
 #define DEF_FONT	"-b&h-lucida-medium-r-normal-sans-24-*-*-*-*-*-iso8859-1"
 #endif /* !AIXV3 */
 #endif
-#define DEF_MSGFONT     "-adobe-courier-medium-r-*-*-14-*-*-*-m-*-iso8859-1"
+#define DEF_PLANFONT     "-adobe-courier-medium-r-*-*-14-*-*-*-m-*-iso8859-1"
 #ifdef USE_MB
 #define DEF_FONTSET	DEF_FONT ## ",-*-24-*"
 #endif
@@ -183,8 +185,11 @@ static int  descr();
 /* #define DEF_MESSAGE "I am out running around." */
 #define DEF_MESSAGE ""
 #endif
-#ifndef DEF_IMAGEFILE
-#define DEF_IMAGEFILE ""
+#ifndef DEF_BITMAP
+#define DEF_BITMAP ""
+#endif
+#ifndef DEF_MAILAPP
+#define DEF_MAILAPP ""
 #endif
 #define DEF_CLASSNAME	"XLock"
 /*-
@@ -226,6 +231,12 @@ static int  descr();
 #endif
 #endif
 
+#ifdef USE_DPMS
+#define DEF_DPMSSTANDBY "-1"
+#define DEF_DPMSSUSPEND "-1"
+#define DEF_DPMSOFF     "-1"
+#endif
+
 #if defined( USE_BUTTON_LOGOUT )
 #if !defined( DEF_BUTTON_LOGOUT )
 #if ( USE_BUTTON_LOGOUT <= 0 )
@@ -253,14 +264,11 @@ extern Display *dsp;
 extern char *program;
 extern char *messagesfile;
 extern char *messagefile;
-extern char *message;
-extern char *mfont;
-
-/* For modes with images: xbm, xpm, and ras */
-char       *imagefile;
+extern char *message;		/* flag as well here */
+extern char *messagefontname;
 
 /* For automata modes */
-int         neighbors;
+extern int  neighbors;
 
 /* For eyes, julia, & swarm modes */
 Bool        mouse;
@@ -331,7 +339,7 @@ static XrmOptionDescRec genTable[] =
 	{"-lockdelay", ".lockdelay", XrmoptionSepArg, (caddr_t) NULL},
 	{"-timeout", ".timeout", XrmoptionSepArg, (caddr_t) NULL},
 	{"-font", ".font", XrmoptionSepArg, (caddr_t) NULL},
-	{"-msgfont", ".msgfont", XrmoptionSepArg, (caddr_t) NULL},
+	{"-planfont", ".planfont", XrmoptionSepArg, (caddr_t) NULL},
 #ifdef USE_MB
 	{"-fontset", ".fontset", XrmoptionSepArg, (caddr_t) NULL},
 #endif
@@ -366,7 +374,7 @@ static XrmOptionDescRec genTable[] =
 	{"-messagesfile", ".messagesfile", XrmoptionSepArg, (caddr_t) NULL},
 	{"-messagefile", ".messagefile", XrmoptionSepArg, (caddr_t) NULL},
 	{"-message", ".message", XrmoptionSepArg, (caddr_t) NULL},
-	{"-mfont", ".mfont", XrmoptionSepArg, (caddr_t) NULL},
+	{"-messagefont", ".messagefont", XrmoptionSepArg, (caddr_t) NULL},
     /* For automata modes */
 	{"-neighbors", ".neighbors", XrmoptionSepArg, (caddr_t) NULL},
     /* For eyes and julia modes */
@@ -398,6 +406,15 @@ static XrmOptionDescRec genTable[] =
 	{"-startCmd", ".startCmd", XrmoptionSepArg, (caddr_t) NULL},
 	{"-endCmd", ".endCmd", XrmoptionSepArg, (caddr_t) NULL},
 	{"-logoutCmd", ".logoutCmd", XrmoptionSepArg, (caddr_t) NULL},
+
+	{"-mailCmd", ".mailCmd", XrmoptionSepArg, (caddr_t) ""},
+	{"-mailIcon", ".mailIcon", XrmoptionSepArg, (caddr_t) ""},
+	{"-nomailIcon", ".nomailIcon", XrmoptionSepArg, (caddr_t) ""},
+#ifdef USE_DPMS
+        {"-dpmsstandby", ".dpmsstandby", XrmoptionSepArg, (caddr_t) NULL},
+        {"-dpmssuspend", ".dpmssuspend", XrmoptionSepArg, (caddr_t) NULL},
+        {"-dpmsoff", ".dpmsoff", XrmoptionSepArg, (caddr_t) NULL},
+#endif
 };
 
 #define genEntries (sizeof genTable / sizeof genTable[0])
@@ -411,7 +428,7 @@ static XrmOptionDescRec modeTable[] =
 	{"-ncolors", "*ncolors", XrmoptionSepArg, (caddr_t) NULL},
 	{"-saturation", "*saturation", XrmoptionSepArg, (caddr_t) NULL},
     /* For modes with images, xbm, xpm, & ras */
-	{"-imagefile", "*imagefile", XrmoptionSepArg, (caddr_t) NULL},
+	{"-bitmap", "*bitmap", XrmoptionSepArg, (caddr_t) NULL},
 };
 
 #define modeEntries (sizeof modeTable / sizeof modeTable[0])
@@ -470,7 +487,11 @@ static OptionStruct opDesc[] =
 	{"-ncolors num", "maximum number of colors, default is 64"},
 	{"-saturation value", "saturation of color ramp"},
   /* For modes with images, xbm, xpm, & ras */
-	{"-imagefile filename", "image file"},
+#if defined( USE_XPM ) || defined( USE_XPMINC )
+	{"-bitmap filename", "bitmap file (sometimes xpm and ras too)"},
+#else
+	{"-bitmap filename", "bitmap file (sometimes ras too)"},
+#endif
 	{"-/+nolock", "turn on/off no password required"},
 	{"-/+inwindow", "turn on/off making xlock run in a window"},
 	{"-/+inroot", "turn on/off making xlock run in the root window"},
@@ -499,7 +520,7 @@ static OptionStruct opDesc[] =
 	{"-lockdelay seconds", "number of seconds until lock"},
 	{"-timeout seconds", "number of seconds before password times out"},
 	{"-font fontname", "font to use for password prompt"},
-	{"-msgfont fontname", "font to use for message"},
+	{"-planfont fontname", "font to use for plan message"},
 #ifdef USE_MB
 	{"-fontset fontsetname", "fontset to use for Xmb..."},
 #endif
@@ -528,10 +549,10 @@ static OptionStruct opDesc[] =
 
     /* For modes with text, marquee & nose */
    {"-program programname", "program to get messages from, usually fortune"},
-	{"-messagesfile formatted-filename", "formatted file message to say"},
-	{"-messagefile filename", "file message to say"},
-	{"-message string", "message to say"},
-	{"-mfont mode-fontname", "font for a specific mode"},
+	{"-messagesfile formatted-filename", "formatted file of fortunes"},
+	{"-messagefile filename", "text file for mode"},
+	{"-message string", "text for mode"},
+	{"-messagefont fontname", "font for a specific mode"},
     /* For automata modes */
       {"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
     /* For eyes and julia modes */
@@ -561,17 +582,28 @@ static OptionStruct opDesc[] =
 	{"-startCmd string", "command to run at locktime"},
 	{"-endCmd string", "command to run when unlocking"},
       {"-logoutCmd string", "command to run when automatically logging out"},
+	{"-mailCmd string", "command to run to check for mail"},
+	{"-mailIcon string", "Icon to display when there is mail"},
+	{"-nomailIcon string", "Icon to display when there is no mail"},
+#ifdef USE_DPMS
+	{"-dpmsstandby seconds", "seconds to wait before engaging DPMS standby"},
+	{"-dpmssuspend seconds", "seconds to wait before engaging DPMS suspend"},
+	{"-dpmsoff seconds", "seconds to wait before engaging DPMS off"},
+#endif
 };
 
 #define opDescEntries (sizeof opDesc / sizeof opDesc[0])
 
 int         delay;
-int         batchcount;
+int         count;
 int         cycles;
 int         size;
 int         ncolors;
 float       saturation;
 
+/* For modes with images, xbm, xpm, & ras */
+char       *bitmap;
+
 #ifdef USE_MODULES
 char       *modulepath;
 
@@ -614,7 +646,13 @@ int         lockdelay;
 int         timeout;
 
 char       *fontname;
-char       *messagefont;
+char       *planfontname;
+
+#ifdef USE_DPMS
+int         dpmsstandby;
+int         dpmssuspend;
+int         dpmsoff;
+#endif
 
 #ifdef USE_MB
 char       *fontsetname;
@@ -684,6 +722,10 @@ char       *startCmd;
 char       *endCmd;
 char       *logoutCmd;
 
+char       *mailCmd;
+char       *mailIcon;
+char       *nomailIcon;
+
 static argtype genvars[] =
 {
     {(caddr_t *) & allowaccess, "allowaccess", "AllowAccess", "off", t_Bool},
@@ -710,7 +752,7 @@ static argtype genvars[] =
    {(caddr_t *) & lockdelay, "lockdelay", "LockDelay", DEF_LOCKDELAY, t_Int},
 	{(caddr_t *) & timeout, "timeout", "Timeout", DEF_TIMEOUT, t_Int},
 	{(caddr_t *) & fontname, "font", "Font", DEF_FONT, t_String},
-    {(caddr_t *) & messagefont, "msgfont", "MsgFont", DEF_MSGFONT, t_String},
+{(caddr_t *) & planfontname, "planfont", "PlanFont", DEF_PLANFONT, t_String},
 #ifdef USE_MB
     {(caddr_t *) & fontsetname, "fontset", "FontSet", DEF_FONTSET, t_String},
 #endif
@@ -744,7 +786,7 @@ static argtype genvars[] =
 	{(caddr_t *) & messagesfile, "messagesfile", "Messagesfile", DEF_MESSAGESFILE, t_String},
 	{(caddr_t *) & messagefile, "messagefile", "Messagefile", DEF_MESSAGEFILE, t_String},
 	{(caddr_t *) & message, "message", "Message", DEF_MESSAGE, t_String},
-	{(caddr_t *) & mfont, "mfont", "MFont", DEF_MFONT, t_String},
+	{(caddr_t *) & messagefontname, "messagefont", "MessageFont", DEF_MESSAGEFONT, t_String},
    {(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int},
 	{(caddr_t *) & mouse, "mouse", "Mouse", DEF_MOUSE, t_Bool},
 
@@ -772,8 +814,15 @@ static argtype genvars[] =
 	{(caddr_t *) & startCmd, "startCmd", "StartCmd", "", t_String},
 	{(caddr_t *) & endCmd, "endCmd", "EndCmd", "", t_String},
 	{(caddr_t *) & logoutCmd, "logoutCmd", "LogoutCmd", "", t_String},
+#ifdef USE_DPMS
+	{(caddr_t *) & dpmsstandby, "dpmsstandby", "DPMSStandby", DEF_DPMSSTANDBY, t_Int},
+	{(caddr_t *) & dpmssuspend, "dpmssuspend", "DPMSSuspend", DEF_DPMSSUSPEND, t_Int},
+	{(caddr_t *) & dpmsoff, "dpmsoff", "DPMSOff", DEF_DPMSOFF, t_Int},
+#endif
 
-
+	{(caddr_t *) & mailCmd, "mailCmd", "MailCmd", DEF_MAILAPP, t_String},
+     {(caddr_t *) & mailIcon, "mailIcon", "MailIcon", DEF_MAILAPP, t_String},
+{(caddr_t *) & nomailIcon, "nomailIcon", "NomailIcon", DEF_MAILAPP, t_String},
 #if 0
     /* These resources require special handling.  They must be examined
      * before the display is opened.  They are evaluated by individual
@@ -792,12 +841,12 @@ static argtype genvars[] =
 static argtype modevars[] =
 {
 	{(caddr_t *) & delay, "delay", "Delay", DEF_DELAY, t_Int},
-{(caddr_t *) & batchcount, "batchcount", "BatchCount", DEF_BATCHCOUNT, t_Int},
+	{(caddr_t *) & count, "batchcount", "BatchCount", DEF_COUNT, t_Int},
 	{(caddr_t *) & cycles, "cycles", "Cycles", DEF_CYCLES, t_Int},
 	{(caddr_t *) & size, "size", "Size", DEF_SIZE, t_Int},
 	{(caddr_t *) & ncolors, "ncolors", "NColors", DEF_NCOLORS, t_Int},
 	{(caddr_t *) & saturation, "saturation", "Saturation", DEF_SATURATION, t_Float},
- {(caddr_t *) & imagefile, "imagefile", "Imagefile", DEF_IMAGEFILE, t_String}
+	{(caddr_t *) & bitmap, "bitmap", "Bitmap", DEF_BITMAP, t_String}
 };
 
 #define NMODEARGS (sizeof modevars / sizeof modevars[0])
@@ -805,12 +854,12 @@ static argtype modevars[] =
 static int  modevaroffs[NMODEARGS] =
 {
 	offsetof(LockStruct, def_delay),
-	offsetof(LockStruct, def_batchcount),
+	offsetof(LockStruct, def_count),
 	offsetof(LockStruct, def_cycles),
 	offsetof(LockStruct, def_size),
 	offsetof(LockStruct, def_ncolors),
 	offsetof(LockStruct, def_saturation),
-	offsetof(LockStruct, def_imagefile)
+	offsetof(LockStruct, def_bitmap)
 };
 
 #ifdef VMS
@@ -908,6 +957,35 @@ Version(void)
 	exit(0);
 }
 
+static void
+checkSpecialArgs(int argc, char **argv)
+{
+	int         i;
+
+	for (i = 0; i < argc; i++) {
+		if (!strncmp(argv[i], "-help", strlen(argv[i])))
+			Help();
+		if (!strncmp(argv[i], "-version", strlen(argv[i])))
+			Version();
+#ifdef CHECK_OLD_ARGS
+		{
+			char       *depreciated_args[] =
+			{"-v", "-imagefile", "-mfont"};
+			char       *current_args[] =
+			{"-verbose", "-bitmap", "-messagefont"};
+			int         j;
+
+			for (j = 0; j < (sizeof (current_args)) / sizeof (*(current_args)); j++)
+				if (!strncmp(argv[i], depreciated_args[j], strlen(argv[i]))) {
+					(void) printf("%s depreciated, use %s\n",
+					depreciated_args[j], current_args[j]);
+					exit(0);
+				}
+		}
+#endif
+	}
+}
+
 static void
 DumpResources(void)
 {
@@ -923,7 +1001,7 @@ DumpResources(void)
 		(void) printf("%s.%s.%s: %d\n", classname, LockProcs[i].cmdline_arg,
 			      "delay", LockProcs[i].def_delay);
 		(void) printf("%s.%s.%s: %d\n", classname, LockProcs[i].cmdline_arg,
-			      "batchcount", LockProcs[i].def_batchcount);
+			      "count", LockProcs[i].def_count);
 		(void) printf("%s.%s.%s: %d\n", classname, LockProcs[i].cmdline_arg,
 			      "cycles", LockProcs[i].def_cycles);
 		(void) printf("%s.%s.%s: %d\n", classname, LockProcs[i].cmdline_arg,
@@ -933,8 +1011,8 @@ DumpResources(void)
 		(void) printf("%s.%s.%s: %g\n", classname, LockProcs[i].cmdline_arg,
 			      "saturation", LockProcs[i].def_saturation);
 		(void) printf("%s.%s.%s: %s\n", classname, LockProcs[i].cmdline_arg,
-			      "imagefile",
-			      (LockProcs[i].def_imagefile) ? LockProcs[i].def_imagefile : "");
+			      "bitmap",
+		   (LockProcs[i].def_bitmap) ? LockProcs[i].def_bitmap : "");
 		for (j = 0; j < LockProcs[i].msopt->numvarsdesc; j++)
 			(void) printf("%s.%s.%s: %s\n", classname, LockProcs[i].cmdline_arg,
 				      LockProcs[i].msopt->vars[j].name,
@@ -943,7 +1021,6 @@ DumpResources(void)
 	exit(0);
 }
 
-
 static void
 LowerString(char *s)
 {
@@ -1394,26 +1471,24 @@ getResources(int argc, char **argv)
 	 * Moved back because its annoying if you need -remote and
 	 * you do not know it.
 	 */
-	for (i = 0; i < argc; i++) {
-		if (!strncmp(argv[i], "-help", strlen(argv[i])))
-			Help();
-		if (!strncmp(argv[i], "-version", strlen(argv[i])))
-			Version();
-	}
+	checkSpecialArgs(argc, argv);
 #endif
 
+	/* Application Class is fixed */
+	classname = DEF_CLASSNAME;
 	/*
-	 * get -name arg from command line so you can have different resource
-	 * files for different configurations/machines etc...
+	 * Application Name may be modified by -name arg from command
+	 * line so you can have different resource files for different
+	 * configurations/machines etc...
 	 */
 #ifdef VMS
 	/*Strip off directory and .exe; parts */
 	ProgramName = stripname(ProgramName);
 #endif
-	XrmParseCommand(&nameDB, nameTable, 1, ProgramName,
+	XrmParseCommand(&nameDB, nameTable, 1, "xlock",
 			&argc, argv);
-	GetResource(nameDB, ProgramName, "*", "name", "Name", t_String,
-		    DEF_CLASSNAME, &classname);
+	GetResource(nameDB, "xlock", classname, "name", "Name", t_String,
+		    ProgramName, &ProgramName);
 
 
 	homeenv = getenv("HOME");
@@ -1526,13 +1601,7 @@ getResources(int argc, char **argv)
 	 * Moved the search for help to here because now the modules
 	 * have been loaded so they can be listed by help.
 	 */
-
-	for (i = 0; i < argc; i++) {
-		if (!strncmp(argv[i], "-help", strlen(argv[i])))
-			Help();
-		if (!strncmp(argv[i], "-version", strlen(argv[i])))
-			Version();
-	}
+	checkSpecialArgs(argc, argv);
 #endif
 
 	XrmParseCommand(&generalDB, genTable, genEntries, ProgramName, &argc, argv);
@@ -1709,15 +1778,15 @@ getResources(int argc, char **argv)
 				       nameOfVisualClass(VisualClassWanted));
 	}
 #if HAVE_DIRENT_H
-	/* Evaluate imagefile */
-	if (imagefile && strcmp(imagefile, DEF_IMAGEFILE)) {
+	/* Evaluate bitmap */
+	if (bitmap && strcmp(bitmap, DEF_BITMAP)) {
 		extern void get_dir(char *fullpath, char *dir, char *filename);
 		extern int  sel_image(struct dirent *name);
 		extern int  scan_dir(const char *directoryname, struct dirent ***namelist,
 				     int         (*select) (struct dirent *),
 			int         (*compare) (const void *, const void *));
 
-		get_dir(imagefile, directory_r, filename_r);
+		get_dir(bitmap, directory_r, filename_r);
 		images_list = (struct dirent ***) malloc(sizeof (struct dirent **));
 
 		num_list = scan_dir(directory_r, images_list, sel_image, NULL);
@@ -1732,7 +1801,6 @@ getResources(int argc, char **argv)
 #endif
 	(void) free((void *) modename);
 	(void) free((void *) modeclassname);
-	(void) free((void *) classname);
 }
 
 
@@ -1760,8 +1828,7 @@ checkResources(void)
 		Syntax(mode);
 	} else {
 
-		/* batchcount and size we allow negative
-		   to mean randomize up to that number */
+		/* count and size we allow negative to mean randomize up to that number */
 		if (delay < 0)
 			Syntax("-delay argument must not be negative.");
 		if (cycles < 0)
