@@ -49,6 +49,8 @@ static LockStruct LockProcs[] =
 	 "Shows Griffeath's cellular automata"},
 	{"dilemma",
 	 "Shows Lloyd's Prisoner's Dilemma simulation"},
+	{"discrete",
+	 "Shows various discrete maps"},
 	{"drift",
 	 "Shows cosmic drifting flame fractals"},
 	{"eyes",
@@ -59,6 +61,8 @@ static LockStruct LockProcs[] =
 	 "Shows a waving flag of your operating system"},
 	{"flame",
 	 "Shows cosmic flame fractals"},
+	{"flow",
+	 "Shows dynamic strange attractors"},
 	{"forest",
 	 "Shows binary trees of a fractal forest"},
 	{"galaxy",
@@ -67,6 +71,8 @@ static LockStruct LockProcs[] =
 	{"gears",
 	 "Shows GL's gears"},
 #endif
+	{"goop",
+	 "Shows goop from a lava lamp"},
 	{"grav",
 	 "Shows orbiting planets"},
 	{"helix",
@@ -173,6 +179,8 @@ static LockStruct LockProcs[] =
 	 "Shows a swarm of bees following a wasp"},
 	{"swirl",
 	 "Shows animated swirling patterns"},
+	{"thornbird",
+	 "Shows an animated Bird in a Thorn Bush fractal map"},
 	{"triangle",
 	 "Shows a triangle mountain range"},
 	{"tube",
